@@ -449,7 +449,7 @@ class AppInstall(SimpleGladeApp):
     def error_no_indexfiles(self):
         """ show an error message that no index files could be found
         """
-        header = _("The list of applications is not availabe")
+        header = _("The list of applications is not available")
         msg = _("Click on 'Reload' to load it. To reload the "
                 "list you need a working internet connection. ")
         d = gtk.MessageDialog(parent=self.window_main,
@@ -676,7 +676,7 @@ class AppInstall(SimpleGladeApp):
                      "* You are using this software for research "
                      "purposes only")
             dia.set_markup("<big><b>%s</b></big>\n\n%s" % (header,body))
-            dia.add_button(_("_Confirm"), gtk.RESPONSE_OK)
+            dia.add_button(_("C_onfirm"), gtk.RESPONSE_OK)
             res = dia.run()
             dia.hide()
             if res != gtk.RESPONSE_OK:
@@ -1020,7 +1020,21 @@ class AppInstall(SimpleGladeApp):
     # ----------------------------
 
     def on_button_help_clicked(self, widget):
-        subprocess.Popen(["/usr/bin/yelp", "ghelp:gnome-app-install"])
+        if os.path.exists("/usr/bin/yelp"):
+            subprocess.Popen(["/usr/bin/yelp", "ghelp:gnome-app-install"])
+        else:
+            d = gtk.MessageDialog(parent=self.window_main,
+                                  flags=gtk.DIALOG_MODAL,
+                                  type=gtk.MESSAGE_ERROR,
+                                  buttons=gtk.BUTTONS_CLOSE)
+            header = _("No help available")
+            msg = _("To display the help, you need to install the "
+                    "\"yelp\" application.")
+            d.set_title("")
+            d.set_markup("<big><b>%s</b></big>\n\n%s" % (header, msg))
+            d.run()
+            d.destroy()
+
 
     def applyChanges(self, to_add, to_rm):
         """
