@@ -7,6 +7,8 @@ import os
 from Util import *
 from gettext import gettext as _
 
+from widgets.AppListView import AppListView
+
 class DialogMultipleApps(SimpleGladeApp):
 
     def __init__(self, datadir, parent, multiple_items_list, name, remove):
@@ -14,16 +16,19 @@ class DialogMultipleApps(SimpleGladeApp):
                                 path=datadir+"/gnome-app-install.glade",
                                 root="dialog_multiple_apps",
                                 domain="gnome-app-install")
-                                
-                                
         self.store = gtk.ListStore(gobject.TYPE_STRING,
-                                   gobject.TYPE_PYOBJECT)
+                                   gobject.TYPE_PYOBJECT,
+                                   gobject.TYPE_INT)
         for elm in multiple_items_list:
-            self.store.append((elm.name,elm))
-        self.treeview_multiple_apps.set_model(self.store)
+            self.store.append((elm.name, elm, 0))
         self.dialog_multiple_apps.set_transient_for(parent)
-        self.init_treeview(self.treeview_multiple_apps)
-
+        # Setup the application list
+        self.treeview_apps = AppListView(style=1)
+        self.scrolledwindow_multiple_apps.add(self.treeview_apps)
+        self.treeview_apps.set_headers_visible(False)
+        self.treeview_apps.set_model(self.store)
+        self.treeview_apps.show()
+        # Create the dialog message text
         if remove == True:
             header = (_("Remove %s and bundled applications?") % name)
             msg = _("%s is part of a software collection. If you remove "
@@ -45,31 +50,3 @@ class DialogMultipleApps(SimpleGladeApp):
 
     def hide(self):
         self.dialog_multiple_apps.hide()
-
-    # this code is identical to DialogPendingChanges - merge
-    def init_treeview(self, view):
-        def package_view_func(cell_layout, renderer, model, iter):
-            (name, item) = model.get(iter, 0, 1)
-            renderer.set_property("markup",
-                                  "%s\n<small>%s</small>" % \
-                                  (item.name, item.description))
-        def icon_cell_func(column, cell, model, iter):
-            menuitem = model.get_value(iter, 1)
-            if menuitem.iconname != None:
-                icon = menuitem.icontheme._getIcon(menuitem.iconname, 24)
-                cell.set_property("pixbuf", icon)
-            else:
-                cell.set_property("pixbuf", None)
-            cell.set_property("visible", True)
-        view.set_search_column(COL_NAME)
-        view.get_selection().set_mode(gtk.SELECTION_NONE)
-        column = gtk.TreeViewColumn("")
-        render = gtk.CellRendererPixbuf()
-        column.pack_start(render, False)
-        column.set_cell_data_func (render, icon_cell_func)
-        render = gtk.CellRendererText()
-        render.set_property("xpad", 4)
-        column.pack_start(render, True)
-        column.add_attribute(render, "markup", COL_NAME)
-        column.set_cell_data_func (render, package_view_func)
-        view.append_column(column)
