@@ -87,10 +87,15 @@ class SearchActivationStyle(ActivationStyle):
         self._wl_packages = dict
 
         # read the component whitelist (from gconf)
-        client = gconf.client_get_default()
-        l = client.get_list("/apps/gnome-app-install"+
-                            "/mime-whitelist-components",
-                            gconf.VALUE_STRING)
+        try:
+            client = gconf.client_get_default()
+            l = client.get_list("/apps/gnome-app-install"+
+                                "/mime-whitelist-components",
+                                gconf.VALUE_STRING)
+        except gobject.GError, e:
+            # default to "main" if gconf is not available
+            print "Error in gconf: %s" % e
+            l = ["main"]
         dict = {}
         for v in l: dict[v] = True
         self._wl_components = dict
